@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/afs_osi.c,v 1.7 2001/07/12 19:58:15 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/afs_osi.c,v 1.8.2.1 2001/11/10 23:22:48 shadow Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -72,7 +72,7 @@ void osi_Init()
 
 	if ( !afs_osicred_initialized )
 	{
-		bzero((char *)&afs_osi_cred, sizeof(struct AFS_UCRED));
+		memset((char *)&afs_osi_cred, 0, sizeof(struct AFS_UCRED));
 		crhold(&afs_osi_cred);      /* don't let it evaporate */
 		afs_osicred_initialized = 1;
 	}
@@ -300,6 +300,7 @@ void afs_osi_Invisible() {
     set_system_proc(u.u_procp);
 #else
 #if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+    /* maybe call init_process instead? */
     current_proc()->p_flag |= P_SYSTEM;
 #else
 #if !defined(AFS_SGI64_ENV) && !defined(AFS_LINUX20_ENV)
@@ -935,7 +936,7 @@ const struct AFS_UCRED *afs_osi_proc2cred(AFS_PROC *pr)
        cr.cr_ref=1;
        cr.cr_uid=pr->p_cred->pc_ucred->cr_uid;
        cr.cr_ngroups=pr->p_cred->pc_ucred->cr_ngroups;
-       bcopy(pr->p_cred->pc_ucred->cr_groups, cr.cr_groups,NGROUPS *
+       memcpy(cr.cr_groups, pr->p_cred->pc_ucred->cr_groups, NGROUPS *
              sizeof(gid_t));
        pcred_unlock(pr);
        rv = &cr;
