@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/bozo/bnode.c,v 1.6 2001/07/12 19:58:26 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/bozo/bnode.c,v 1.7.2.1 2001/10/13 04:21:04 shadow Exp $");
 
 #include <stddef.h>
 #include <stdlib.h>
@@ -34,6 +34,11 @@ RCSID("$Header: /cvs/openafs/src/bozo/bnode.c,v 1.6 2001/07/12 19:58:26 shadow E
 #include <afs/fileutil.h>
 #include "bnode.h"
 
+#ifdef AFS_AIX_ENV
+/* All known versions of AIX lack WCOREDUMP but this works */
+#define WCOREDUMP(x) ((x) & 0x80)
+#endif
+
 #define BNODE_LWP_STACKSIZE	(16 * 1024)
 
 int bnode_waiting = 0;
@@ -281,7 +286,7 @@ struct bnode_ops *aprocs; {
     }
     if (!tt) {
 	tt = (struct bnode_type *) malloc(sizeof(struct bnode_type));
-	bzero(tt, sizeof(struct bnode_type));
+	memset(tt, 0, sizeof(struct bnode_type));
 	tt->next = allTypes;
 	allTypes = tt;
 	tt->name = atype;
@@ -425,7 +430,7 @@ struct bnode_ops *abnodeops; {
     struct bnode **lb, *nb;
 
     /* format the bnode properly */
-    bzero(abnode, sizeof(struct bnode));
+    memset(abnode, 0, sizeof(struct bnode));
     abnode->ops = abnodeops;
     abnode->name = (char *) malloc(strlen(aname)+1);
     strcpy(abnode->name, aname);
@@ -528,6 +533,12 @@ static int bproc() {
 			    RememberProcName(tp);
 			    tb->errorSignal = 0;
 			}
+			if (tp->coreName)
+			    bozo_Log("%s:%s exited with code %d",
+				tb->name, tp->coreName, tp->lastExit);
+			else
+			    bozo_Log("%s exited with code %d",
+				tb->name, tp->lastExit);
 		    }
 		    else {
 			/* Signal occurred, perhaps spurious due to shutdown request.
@@ -542,6 +553,14 @@ static int bproc() {
 			    tb->lastErrorExit = FT_ApproxTime();
 			    RememberProcName(tp);
 			}
+			if (tp->coreName)
+			    bozo_Log("%s:%s exited on signal %d%s",
+				tb->name, tp->coreName, tp->lastSignal,
+				WCOREDUMP(status) ? " (core dumped)" : "");
+			else
+			    bozo_Log("%s exited on signal %d%s",
+				tb->name, tp->lastSignal,
+				WCOREDUMP(status) ? " (core dumped)" : "");
 			SaveCore(tb, tp);
 		    }
 		    tb->lastAnyExit = FT_ApproxTime();
@@ -733,13 +752,13 @@ int bnode_Init() {
 
     if (initDone) return 0;
     initDone = 1;
-    bzero(&bnode_stats, sizeof(bnode_stats));
+    memset(&bnode_stats, 0, sizeof(bnode_stats));
     LWP_InitializeProcessSupport(1, &junk); /* just in case */
     IOMGR_Initialize();
     code = LWP_CreateProcess(bproc, BNODE_LWP_STACKSIZE,
 			     /* priority */ 1, /* parm */0, "bnode-manager", &bproc_pid);
     if (code) return code;
-    bzero((char *)&newaction, sizeof(newaction));
+    memset((char *)&newaction, 0, sizeof(newaction));
     newaction.sa_handler = bnode_Int;
     code = sigaction(SIGCHLD, &newaction, NULL);
     if (code) return errno;
@@ -831,7 +850,7 @@ char *aexecString; {
     code = bnode_ParseLine(aexecString, &tlist);  /* try parsing first */
     if (code) return code;
     tp = (struct bnode_proc *) malloc(sizeof(struct bnode_proc));
-    bzero(tp, sizeof(struct bnode_proc));
+    memset(tp, 0, sizeof(struct bnode_proc));
     tp->next = allProcs;
     allProcs = tp;
     *aproc = tp;
