@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/bozo/bos.c,v 1.10.2.3 2001/10/13 04:21:04 shadow Exp $");
+
 #include <afs/stds.h>
 #include <stdlib.h>
 #include <stddef.h>
@@ -53,7 +57,6 @@ static IStatServer();
 static DoStat();
 
 #include "bosint.h"
-#include "../permit_xprt.h"
 
 #define MRAFS_OFFSET  9
 #define ADDPARMOFFSET 26
@@ -175,7 +178,7 @@ struct cmd_syndesc *as; {
 	printf("bos: can't find address for host '%s'\n", hostname);
 	exit(1);
     }
-    bcopy(th->h_addr, &addr, sizeof(afs_int32));
+    memcpy(&addr, th->h_addr, sizeof(afs_int32));
 
     /* get tokens for making authenticated connections */
     localauth = (as->parms[ADDPARMOFFSET + 2].items != 0);
@@ -286,7 +289,7 @@ afs_int32 alen; {
     register char *tp;
 
     strcpy(aresult, adir);
-    tp = rindex(aname, '/');
+    tp = strrchr(aname, '/');
     if (!tp) {
 	/* no '/' in name */
 	strcat(aresult, "/");
@@ -384,6 +387,7 @@ register struct cmd_syndesc *as; {
 	    printf("\n");
 	}
     }
+    return 0;
 }
 
 static UnInstall(as)
@@ -782,7 +786,7 @@ register struct cmd_syndesc *as; {
     char buf[BUFSIZ], ver[BUFSIZ];
     
     tconn = GetConn(as, 1);
-    bzero(&tkey, sizeof(struct ktc_encryptionKey));
+    memset(&tkey, 0, sizeof(struct ktc_encryptionKey));
 
 	if(as->parms[1].items)
 		strcpy(buf,as->parms[1].items->data);
@@ -1255,7 +1259,10 @@ char *orphans;
     parms[1] = "now";	    /* when to do it */
     code = BOZO_CreateBnode(aconn, "cron", "salvage-tmp", parms[0], parms[1],
 			    parms[2], parms[3], parms[4], notifier);
-    if (code) goto done;
+    if (code) {
+	printf("bos: failed to start 'salvager' (%s)\n", em(code));
+	goto done;
+    }
     /* now wait for bnode to disappear */
     while (1) {
 	IOMGR_Sleep(5);
@@ -1347,7 +1354,7 @@ struct cmd_syndesc *as; {
     char *orphans;
     char *tp;
 
-    bzero(&mrafsParm, sizeof(mrafsParm));
+    memset(&mrafsParm, 0, sizeof(mrafsParm));
     
     /* parm 0 is machine name, 1 is partition, 2 is volume, 3 is -all flag */
     tconn = GetConn(as, 0);
@@ -1481,7 +1488,6 @@ struct cmd_syndesc *as; {
 	/* now do the salvage operation */
 	printf("Starting salvage.\n");
 	rc = DoSalvage(tconn, (char *) 0, (char *) 0, outName, showlog,parallel,tmpDir,orphans);
-	if (rc) printf("bos: failed to start 'salvager' (%s)\n", em(rc));
 	if (curGoal == BSTAT_NORMAL) {
 	    printf("bos: restarting fs.\n");
 	    code = BOZO_SetTStatus(tconn, "fs", BSTAT_NORMAL);
@@ -1522,7 +1528,6 @@ struct cmd_syndesc *as; {
 	printf("Starting salvage.\n");
 	rc = DoSalvage(tconn, as->parms[1].items->data, (char *) 0,
 		       outName, showlog,parallel,tmpDir,orphans);
-	if (rc) printf("bos: failed to start 'salvager' (%s)\n", em(rc));
 	if (curGoal == BSTAT_NORMAL) {
 	    printf("bos: restarting fs.\n");
 	    code = BOZO_SetTStatus(tconn, "fs", BSTAT_NORMAL);
@@ -1574,10 +1579,8 @@ struct cmd_syndesc *as; {
 	printf("Starting salvage.\n");
 	rc = DoSalvage(tconn, as->parms[1].items->data, tname, outName,
 		       showlog,parallel,tmpDir,orphans);
-	if (rc) {
-	   printf("bos: failed to start 'salvager' (%s)\n", em(rc));
+	if (rc) 
 	   return rc;
-	}
     }
     return 0;
 }
@@ -1788,8 +1791,8 @@ main(argc, argv)
     afsconf_SawCell = 0;	/* Reset it */
     /* don't check error code, since fails sometimes when we're setting up a
      * system */
-    initialize_cmd_error_table();
-    initialize_bz_error_table();
+    initialize_CMD_error_table();
+    initialize_BZ_error_table();
 
     ts = cmd_CreateSyntax("start", StartServer, 0, "start running a server");
     cmd_AddParm(ts, "-server", CMD_SINGLE, 0, "machine name");
