@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/vlserver/vlprocs.c,v 1.5.2.2 2001/10/13 04:22:10 shadow Exp $");
+
 #include <sys/types.h>
 #include <stdio.h>
 #include <lock.h>
@@ -188,7 +192,7 @@ VL_CreateEntry(rxcall, newentry)
       goto abort;
     }
 
-    bzero(&tentry, sizeof(struct nvlentry));
+    memset(&tentry, 0, sizeof(struct nvlentry));
     /* Convert to its internal representation; both in host byte order */
     if (errorcode = vldbentry_to_vlentry(trans, newentry, &tentry))	{  
 	FreeBlock(trans, blockindex);
@@ -261,7 +265,7 @@ VL_CreateEntryN(rxcall, newentry)
       goto abort;
     }
 
-    bzero(&tentry, sizeof(struct nvlentry));
+    memset(&tentry, 0, sizeof(struct nvlentry));
     /* Convert to its internal representation; both in host byte order */
     if (errorcode = nvldbentry_to_vlentry(trans, newentry, &tentry))	{  
 	FreeBlock(trans, blockindex);
@@ -294,8 +298,7 @@ VL_ChangeAddr(rxcall, ip1, ip2)
   struct rx_call	*rxcall;
   afs_int32 ip1, ip2;
 {   struct ubik_trans	*trans;
-    afs_int32		errorcode, blockindex;
-    struct nvlentry	tentry;
+    afs_int32		errorcode;
 
     COUNT_REQ (VLCHANGEADDR);
     if (!afsconf_SuperUser(vldb_confdir, rxcall, (char *)0)) {
@@ -1036,8 +1039,7 @@ bulkentries		    *vldbentries;
     VldbentryLast = VldbentryFirst + allocCount;
     /* Handle the attribute by volume id totally separate of the rest (thus additional Mask values are ignored if VLLIST_VOLUMEID is set!) */
     if (attributes->Mask & VLLIST_VOLUMEID) {
-	afs_int32	blockindex, chain;
-	struct nvlentry tempentry;
+	afs_int32	blockindex;
 
 	blockindex = FindByID(trans, attributes->volumeid, -1, &tentry, &errorcode);
 	if (blockindex == 0) {
@@ -1144,8 +1146,7 @@ nbulkentries		    *vldbentries;
     VldbentryLast = VldbentryFirst + allocCount;
     /* Handle the attribute by volume id totally separate of the rest (thus additional Mask values are ignored if VLLIST_VOLUMEID is set!) */
     if (attributes->Mask & VLLIST_VOLUMEID) {
-	afs_int32	blockindex, chain;
-	struct nvlentry tempentry;
+	afs_int32	blockindex;
 
 	blockindex = FindByID(trans, attributes->volumeid, -1, &tentry, &errorcode);
 	if (blockindex == 0) {
@@ -1243,7 +1244,7 @@ VL_ListAttributesN2(rxcall, attributes, name, startindex, nentries, vldbentries,
   int			errorcode=0, maxCount=VLDBALLOCCOUNT;
   struct ubik_trans	*trans;
   struct nvlentry	tentry;
-  struct nvldbentry	*Vldbentry=0, *VldbentryFirst=0, *VldbentryLast=0, tVldbentry;
+  struct nvldbentry	*Vldbentry=0, *VldbentryFirst=0, *VldbentryLast=0;
   afs_int32	                blockindex=0, count=0, k, match, matchindex;
   int                   serverindex=-1; /* no server found */
   int                   findserver=0, findpartition=0, findflag=0, findname=0;
@@ -1697,8 +1698,8 @@ vital_vlheader	*vital_header;
     if (errorcode = Init_VLdbase(&trans, LOCKREAD, this_op))
 	return errorcode;
     VLog(5, ("GetStats %\n", rxinfo(rxcall)));
-    bcopy((char *)&cheader.vital_header, (char *) vital_header, sizeof(vital_vlheader));
-    bcopy((char *)&dynamic_statistics, (char *) stats, sizeof(vldstats));
+    memcpy((char *) vital_header, (char *)&cheader.vital_header, sizeof(vital_vlheader));
+    memcpy((char *) stats, (char *)&dynamic_statistics, sizeof(vldstats));
     return(ubik_EndTrans(trans));
 }
 
@@ -1720,7 +1721,7 @@ bulkaddrs		    *addrsp;
     COUNT_REQ(VLGETADDRS);
     addrsp->bulkaddrs_len = *nentries = 0;
     addrsp->bulkaddrs_val = 0;
-    bzero (spare3, sizeof (struct VLCallBack));
+    memset(spare3, 0, sizeof (struct VLCallBack));
 
     if (errorcode = Init_VLdbase(&trans, LOCKREAD, this_op))
 	return errorcode;
@@ -1756,11 +1757,11 @@ VL_RegisterAddrs(rxcall, uuidp, spare1, addrsp)
 {
   afs_int32 code;
   struct ubik_trans *trans;
-  int cnt, h, i, j, k, m, hostslot, base, index;
+  int cnt, h, i, j, k, m, base, index;
   struct extentaddr *exp = 0, *tex;
   afsUUID tuuid;
   afs_uint32 addrs[VL_MAXIPADDRS_PERMH];
-  afs_int32 fbase, findex;
+  afs_int32 fbase;
   int count, willChangeEntry, foundUuidEntry, willReplaceCnt;
   int WillReplaceEntry, WillChange[MAXSERVERID+1], FoundUuid, ReplaceEntry;
   int srvidx, mhidx;
@@ -2098,9 +2099,9 @@ struct ListAddrByAttributes *attributes;
 afsUUID *uuidpo;
 afs_int32  *uniquifier, *nentries;
 bulkaddrs		    *addrsp;
-{   register afs_int32   errorcode, index=-1, op, offset;
+{   register afs_int32   errorcode, index=-1, offset;
     struct ubik_trans	*trans;
-    int nservers, i, j, k, base=0;
+    int nservers, i, j, base=0;
     struct extentaddr *exp=0;
     afsUUID tuuid;
     afs_uint32 *taddrp, taddr;
@@ -2575,7 +2576,7 @@ struct vldbentry    *VldbEntry;
 {
     int i, j;
     
-    bzero(VldbEntry, sizeof(struct vldbentry));
+    memset(VldbEntry, 0, sizeof(struct vldbentry));
     strncpy(VldbEntry->name, VlEntry->name, sizeof(VldbEntry->name));
     for (i=0; i < OMAXNSERVERS; i++) {
 	if (VlEntry->serverNumber[i] == BADSERVERID) break;
@@ -2613,7 +2614,7 @@ struct nvldbentry    *VldbEntry;
 {
     int i, j;
     
-    bzero(VldbEntry, sizeof(struct vldbentry));
+    memset(VldbEntry, 0, sizeof(struct vldbentry));
     strncpy(VldbEntry->name, VlEntry->name, sizeof(VldbEntry->name));
     for (i=0; i < NMAXNSERVERS; i++) {
 	if (VlEntry->serverNumber[i] == BADSERVERID) break;
@@ -2649,7 +2650,7 @@ struct uvldbentry    *VldbEntry;
 {
     int i, j;
     
-    bzero(VldbEntry, sizeof(struct vldbentry));
+    memset(VldbEntry, 0, sizeof(struct vldbentry));
     strncpy(VldbEntry->name, VlEntry->name, sizeof(VldbEntry->name));
     for (i=0; i < NMAXNSERVERS; i++) {
 	if (VlEntry->serverNumber[i] == BADSERVERID) break;
@@ -2790,7 +2791,7 @@ register afs_uint32	ipaddr1, ipaddr2;
     int base, index, mhidx;
     afsUUID tuuid;
     afs_int32 blockindex, count;
-    int   pollcount;
+    int   pollcount = 0;
     struct nvlentry tentry;
 
     if (!atrans)
@@ -2885,7 +2886,7 @@ register afs_uint32	ipaddr1, ipaddr2;
 
     /* Change the registered uuuid addresses */
     if (exp) {
-       bzero(&tuuid, sizeof(afsUUID));
+       memset(&tuuid, 0, sizeof(afsUUID));
        afs_htonuuid(&tuuid);
        exp->ex_hostuuid = tuuid;
        code = vlwrite(atrans, DOFFSET(ntohl(ex_addr[0]->ex_contaddrs[base]),
